Summary: Programs for mounting and unmounting filesystems.
Name: mount
Exclusiveos: Linux
Version: 2.9u
Release: 4
Copyright: GPL
Group: System Environment/Base
Source: ftp://ftp.win.tue.nl/pub/linux/util/mount-%{version}.tar.gz
Patch0: mount-2.9o-standalone.patch
Patch1: mount-2.9i-loop.patch
Patch2: mount-2.9o-sparc.patch
Patch3: mount-2.9u-ownermount.patch
BuildRoot: /var/tmp/%{name}-root
Prereq: mktemp /bin/awk /usr/bin/cmp textutils fileutils

%description
The mount package contains the mount, umount, swapon and swapoff
programs.  Accessible files on your system are arranged in one big
tree or hierarchy.  These files can be spread out over several
devices. The mount command attaches a filesystem on some device to
your system's file tree.  The umount command detaches a filesystem
from the tree.  Swapon and swapoff, respectively, specify and disable
devices and files for paging and swapping.

%package -n losetup
Summary: Programs for setting up and configuring loopback devices.
Group: System Environment/Base

%description -n losetup
Linux supports a special block device called the loop device, which
maps a normal file onto a virtual block device.  This allows for the
file to be used as a "virtual file system" inside another file.
Losetup is used to associate loop devices with regular files or block
devices, to detach loop devices and to query the status of a loop
device.

%prep
%setup -q
%patch0 -p1 -b .standalone
%patch1 -p2 -b .loop
%patch2 -p2 -b .sparc
%patch3 -p1 -b .ownermount

cat << EOF > defines.h
#define HAVE_locale_h	1
EOF

cat << EOF  > version.h
#define	UTIL_LINUX_VERSION "%{version}"
const char * const util_linux_version = "mount " UTIL_LINUX_VERSION;
EOF

%build

( cd lib; cc $RPM_OPT_FLAGS -c setproctitle.c )

make	LIB=./lib \
	BINDIR=/bin \
	SBINDIR=/sbin \
	MANDIR=/usr/man \
	all

%install
rm -rf $RPM_BUILD_ROOT

make	LIB=./lib \
	BINDIR=$RPM_BUILD_ROOT/bin \
	SBINDIR=$RPM_BUILD_ROOT/sbin \
	MAN5DIR=$RPM_BUILD_ROOT/usr/man/man5 \
	MAN8DIR=$RPM_BUILD_ROOT/usr/man/man8 \
	INSTALLDIR="install -d -m 755" \
	INSTALLSUID="install -s -m 755" \
	INSTALLBIN="install -s -m 755" \
	INSTALLMAN="install -m 644" \
	install

%clean
rm -rf $RPM_BUILD_ROOT

%post
if [ -f /etc/fstab ] ; then
    # add owner mounting capability to appropriate devices
    TMP=$(mktemp /tmp/fstab.XXXXXX)
    if awk '
	($1 ~ /^\/dev\/fd[01]$/ || $2 ~ /^\/mnt\/cdrom$/) &&
        $4 !~ /user/ && $4 !~ /owner/ {
            if (match($4, "^defaults$"))
                printf "%%-23s %%-23s %%-7s %%-15s %%s %%s\n", $1, $2, $3, "owner", $5, $6
            else
                printf "%%-23s %%-23s %%-7s %%-15s %%s %%s\n", $1, $2, $3, "owner," $4, $5, $6
            next
	}
	{print ; next}
    ' /etc/fstab > $TMP ; then
	if ! cmp -s /etc/fstab $TMP ; then 
	    cat $TMP > /etc/fstab
	fi
	rm $TMP
    else
	echo "attempt to edit fstab in mount package failed" 1>&2
    fi
fi

%files
%defattr(-,root,root)
%attr(4755,root,root)	/bin/mount
%attr(4755,root,root)	/bin/umount
/sbin/swapon
/sbin/swapoff
/usr/man/man5/fstab.5
/usr/man/man5/nfs.5
/usr/man/man8/mount.8
/usr/man/man8/swapoff.8
/usr/man/man8/swapon.8
/usr/man/man8/umount.8

%files -n losetup
%defattr(-,root,root)
/usr/man/man8/losetup.8
/sbin/losetup

%changelog
* Mon Sep 13 1999 Erik Troan <ewt@redhat.com>
- fixed owner patch <blush>

* Thu Sep 09 1999 Michael K. Johnson <johnsonm@redhat.com>
- added owned patch
- add "owner" option to cdrom and floppy devices unless one of the
  options "owner", "noowner", "user", or "nouser" is already set.
  Set the "noowner" option to keep this change from being made in
  the future.

* Fri Jul 16 1999 Jeff Johnson <jbj@redhat.com>
- update to 2.9u.

* Fri Jun 25 1999 Jeff Johnson <jbj@redhat.com>
- update to 2.9s.

* Thu Apr 15 1999 Jeff Johnson <jbj@redhat.com>
- update to 2.9o.

* Fri Mar 26 1999 Bill Nottingham <notting@redhat.com>
- accept ncpfs/smbfs as valid types, not just ncp/smb

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com> 
- auto rebuild in the new build environment (release 3)

* Sun Mar 14 1999 Jeff Johnson <jbj@redhat.com>
- rebuild to try and get setuid bits in binary package  -- they're in the
  spec file %attr (#1507).

* Mon Jan 18 1999 Jeff Johnson <jbj@redhat.com>
- rebuild for Raw Hide.
- update to mount-2.9 (from util-linux-2.9)

* Tue Oct 06 1998 Cristian Gafton <gafton@redhat.com>
- accept the fact that sometimes the last line in fstab does not have a \n

* Wed Aug  5 1998 Jeff Johnson <jbj@redhat.com>
- update to 2.8a (from util-linux)

* Fri May 01 1998 Prospector System <bugs@redhat.com>
- translations modified for de, fr, tr

* Thu Apr 30 1998 Cristian Gafton <gafton@redhat.com>
- fixed to compile on manhattan

* Wed Apr 08 1998 Erik Troan <ewt@redhat.com>
- updated to mount-2.7l

* Thu Oct 23 1997 Erik Troan <ewt@redhat.com>
- updated for glibc 2.1

* Wed Sep 03 1997 Erik Troan <ewt@redhat.com>
- updated to 2.7f
- added glibc hacks for the Alpha (I don't know why Intel doesn't need them)

* Tue Jun 17 1997 Erik Troan <ewt@redhat.com>
- updated to 2.6h
- built against glibc
